pub struct AccountSyncer { /* private fields */ }Expand description
Account syncer - handles syncing clearinghouse state to upstream API
Implementations
Sourceimpl AccountSyncer
impl AccountSyncer
Sourcepub fn new(config: AccountSyncerConfig) -> Result<Self, SyncError>
pub fn new(config: AccountSyncerConfig) -> Result<Self, SyncError>
Create a new account syncer with the given configuration
Sourcepub fn should_sync(&self) -> bool
pub fn should_sync(&self) -> bool
Check if it’s time to sync (based on interval)
Sourcepub fn set_metrics_snapshot(
&mut self,
snapshot: Option<PerformanceMetricsSnapshot>,
)
pub fn set_metrics_snapshot( &mut self, snapshot: Option<PerformanceMetricsSnapshot>, )
Set the latest performance metrics snapshot for sync metadata.
Sourcepub async fn sync(
&mut self,
account_state: &AccountState,
stop_bot: bool,
stop_reason: &str,
) -> Result<SyncResult, SyncError>
pub async fn sync( &mut self, account_state: &AccountState, stop_bot: bool, stop_reason: &str, ) -> Result<SyncResult, SyncError>
Sync account state to upstream API
Returns the PnL from the upstream API on success
Sourcepub async fn shutdown_sync(
&mut self,
account_state: &AccountState,
stop_reason: &str,
) -> Result<SyncResult, SyncError>
pub async fn shutdown_sync( &mut self, account_state: &AccountState, stop_reason: &str, ) -> Result<SyncResult, SyncError>
Perform final sync on shutdown (with stop_bot=true)