HasItems

Trait HasItems 

pub trait HasItems {
    // Required method
    fn has_items(&self) -> bool;
}
Trait to check if a poll result contains actual data.

Blanket-implemented for Vec<T>, so Vec<Fill>, Vec<Quote>, etc. all satisfy this automatically.

Required Methods

fn has_items(&self) -> bool

Return true when the poll result contains meaningful data.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> HasItems for Vec<T>

Source

fn has_items(&self) -> bool

Implementors